<?php
/**
 * About section
 *
 * This is the template for the content of About section
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

if ( ! function_exists( 'tp_philosophy_pro_add_about_section' ) ) :
    /**
     * Add About section
     *
     * @since 1.0
     */
    function tp_philosophy_pro_add_about_section() {
        // Check if about section is enabled on frontpage

        $about_section_enable = apply_filters( 'tp_philosophy_pro_section_status', true, 'about_enable' );

        if ( true !== $about_section_enable ) {
            return false;
        }

        // Get About section details
        $section_details = array();
        $section_details = apply_filters( 'tp_philosophy_pro_filter_about_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render About section now.
        tp_philosophy_pro_render_about_section( $section_details );
    }
endif;
add_action( 'tp_philosophy_pro_homepage_section', 'tp_philosophy_pro_add_about_section', 20 );

if ( ! function_exists( 'tp_philosophy_pro_get_about_section_details' ) ) :
  /**
   * About section details.
   *
   * @since 1.0
   *
   * @param array $input about section details.
   */
   function tp_philosophy_pro_get_about_section_details( $input ) {
        global $post;
        $options = tp_philosophy_pro_get_theme_options();

        // About section options
        $about_content_type = $options['about_content_type'];
        $about_subtitle     = ! empty( $options['about_subtitle'] ) ? $options['about_subtitle'] : '';
        $read_more_text     = ! empty( $options['about_learn_more_text'] ) ? $options['about_learn_more_text'] : '';

        $content = array();
        switch ( $about_content_type ){
            case 'demo':
                $content['title']           = esc_html__( 'About', 'tp-philosophy-pro' );
                $content['subtitle']        = esc_html__( 'You will love it.', 'tp-philosophy-pro' );
                $content['description']     = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed condimentum mi sit amet nulla sollicitudin interdum. Suspendisse dapibus sapien a enim egestas, id convallis massa cursus. Aliquam efficitur orci ac turpis semper, in vehicula metus aliquet. Donec rutrum consectetur suscipit. Nulla facilisi. Curabitur vulputate elementum leo nec tempor.', 'tp-philosophy-pro' );
                
                $content['read_more_text']  = esc_html__( 'View More', 'tp-philosophy-pro' );
                $content['read_more_link']  = '#';
                $content['thumbnail_image'][0] = get_template_directory_uri() . '/assets/uploads/about.jpg';
            break;

            case 'posts':
                $post_id      = !empty ( $options['about_post_id'] ) ? absint( $options['about_post_id'] ) : '';

                if( empty( $post_id  ) ) return; // Return if post id is empty

                $about_post =  get_post( $post_id ); // get post object by post id

                $content['title']           = get_the_title( $about_post->ID );
                $content['subtitle']        = $about_subtitle;
                
                $content['read_more_text']  = $read_more_text;
                $content['read_more_link']  = get_the_permalink( $about_post->ID );
                
                $content['thumbnail_image'] = array();

                if ( has_post_thumbnail( $about_post->ID ) ) {
                    $content['thumbnail_image'] = wp_get_attachment_image_src( get_post_thumbnail_id( $about_post->ID ), 'tp-philosophy-pro-about-thumbnail' );
                }

                $excerpt_length             = empty( $content['thumbnail_image'] ) ? 150 : 100 ;

                $content['description']     = tp_philosophy_pro_trim_content( absint( $excerpt_length ), $about_post );
            break;

            case 'pages':
                $page_id      = !empty ( $options['about_page_id'] ) ? absint( $options['about_page_id'] ) : '';

                if ( empty( $page_id  ) ) return; // Return if page id is empty

                $about_page = get_post( $page_id ); // Get post object by page id

                $content['title']           = get_the_title( $about_page->ID );
                $content['subtitle']        = $about_subtitle;
                
                $content['read_more_text']  = $read_more_text;
                $content['read_more_link']  = get_the_permalink( $about_page->ID );

                $content['thumbnail_image'] = array();
                
                if ( has_post_thumbnail( $about_page->ID ) ){
                    $content['thumbnail_image'] = wp_get_attachment_image_src( get_post_thumbnail_id( $about_page->ID ), 'tp-philosophy-pro-about-thumbnail' );
                }

                $excerpt_length             = empty( $content['thumbnail_image'] ) ? 150 : 100 ;

                $content['description']     = tp_philosophy_pro_trim_content( absint( $excerpt_length ), $about_page );
            break;

            case 'custom':
                $content['title']           = !empty( $options['about_custom_title'] ) ? $options['about_custom_title'] : '';
                $content['subtitle']        = $about_subtitle;
                $content['description']     = !empty( $options['about_custom_description'] ) ? $options['about_custom_description'] : '';
                
                $content['read_more_text']  = $read_more_text;
                $content['read_more_link']  = !empty( $options['about_custom_link'] ) ? $options['about_custom_link'] : '#';

                $content['thumbnail_image'] = array();

                if ( ! empty( $options['about_custom_image'] ) ){
                    $content['thumbnail_image'][0] = $options['about_custom_image'];
                }
            break;

            default:
            break;
        }
                                                                                                                   
        if ( !empty( $content ) ) {
            $input = $content;
        }
        return $input;
  }
endif;
add_filter( 'tp_philosophy_pro_filter_about_details', 'tp_philosophy_pro_get_about_section_details' );

if ( ! function_exists( 'tp_philosophy_pro_render_about_section' ) ) :
    /**
     * Start About section
     *
     * @return string about section content
     * @since 1.0
     *
     */
    function tp_philosophy_pro_render_about_section( $content ) {
        $options = tp_philosophy_pro_get_theme_options(); // get theme options

        $section_class      = ! empty( $content['thumbnail_image'] ) ? 'col-2' : 'col-1';
        $heading_box_layout = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';
        
        $header_class       = ( 'col-2' == $section_class ) ? 'entry-header '. esc_attr( $heading_box_layout ) .'' : 'entry-header text-center '. esc_attr( $heading_box_layout ) .' border-center' ;

        $button_css         = ( 'col-2' == $section_class ) ? '' : 'center-align' ;
    ?>
        <section id="about" class="<?php echo esc_attr( $section_class ); ?> page-section">
            <div class="wrapper">
                <div class="row">
                    <div class="column-wrapper">
                    <?php if ( ! empty( $content['title'] ) || ! empty( $content['subtitle'] ) ) : ?>
                        <header class="<?php echo esc_attr( $header_class ); ?>">
                        <?php 
                            if ( ! empty( $content['title'] ) ){
                                echo '<h2 class="entry-title">'. esc_html( $content['title'] ) .'</h2>';
                            } 
                            if ( ! empty( $content['subtitle'] ) ){
                                echo '<h3 class="sub-title">'. esc_html( $content['subtitle'] ) .'</h3>';
                            }
                        ?>
                        </header><!--.entry-header-->
                    <?php endif; ?>

                        <div class="entry-content">
                        <?php 
                            if ( ! empty( $content['description'] ) ){
                                echo '<p>'. esc_html( $content['description'] ) .'</p>';
                            }

                            if ( ! empty( $content['read_more_text'] ) ){
                                echo '<a href="'. esc_url( $content['read_more_link'] ).'" class="view-more '. esc_attr( $button_css ) .'"><span data-hover="'. esc_attr( $content['read_more_text'] ) .'">'. esc_html( $content['read_more_text'] ) .'</span></a>';
                            }
                        ?>
                           
                            <div class="background-text">
                                <h1><?php echo esc_html( $content['title'] ); ?></h1>
                            </div><!-- .background-text -->
                        </div><!--.entry-content-->
                    </div><!--.column-wrapper-->

                    <?php if ( ! empty( $content['thumbnail_image'] ) ) : ?>
                        <div class="column-wrapper">
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['read_more_link'] ); ?>"><img src="<?php echo esc_url( $content['thumbnail_image'][0] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>"></a>
                            </div><!--.featured-image-->
                        </div><!--.column-wrapper-->
                    <?php endif; ?>

                </div><!-- .row -->
            </div><!--.wrapper-->
        </section><!--#about-->

    <?php 
    }
endif;